# References

- Kuhlwilm M, Han S, Sousa VC, Excoffier L, Marques-Bonet T. 2019. Ancient admixture from an extinct ape lineage into bonobos. *Nat. Ecol. Evol*. **3**: 957–965. Available from: [https://doi.org/10.1038/s41559-019-0881-7](https://doi.org/10.1038/s41559-019-0881-7)
- Plagnol V, Wall JD. 2006. Possible Ancestral Structure in Human Populations. *PLoS Genet.* **2**: e105. Available from: [http://dx.plos.org/10.1371/journal.pgen.0020105](http://dx.plos.org/10.1371/journal.pgen.0020105])
- Vernot B, Akey JM. 2014. Resurrecting Surviving Neandertal Lineages from Modern Human Genomes. *Science* **343**: 1017–1021. Available from: [http://science.sciencemag.org/content/343/6174/1017.abstract](http://science.sciencemag.org/content/343/6174/1017.abstract)
- Vernot B, Tucci S, Kelso J, Schraiber JG, Wolf AB, Gittelman RM, Dannemann M, Grote S, McCoy RC, Norton H, et al. 2016. Excavating Neandertal and Denisovan DNA from the genomes of Melanesian individuals. *Science* **352**: 235–239. Available from: [http://science.sciencemag.org/content/352/6282/235.abstract](http://science.sciencemag.org/content/352/6282/235.abstract)
